CanvasInputBehavior class
Constructors
- CanvasInputBehavior({bool enablePan = true, bool enableWheelZoom = true, bool enablePinchZoom = true})
-
const
- CanvasInputBehavior.desktop()
-
const
- CanvasInputBehavior.locked()
-
const
- CanvasInputBehavior.touch()
-
const
Properties
- enablePan → bool
-
final
- enablePinchZoom → bool
-
final
- enableWheelZoom → bool
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? enablePan, bool? enableWheelZoom, bool? enablePinchZoom}) → CanvasInputBehavior -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override