CanvasItemBehavior class
Constructors
- CanvasItemBehavior({bool draggable = true, CanvasBringToFrontBehavior bringToFront = CanvasBringToFrontBehavior.never})
-
const
- CanvasItemBehavior.nodeEditor()
-
const
Properties
- bringToFront → CanvasBringToFrontBehavior
-
final
- draggable → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited