CanvasOverlayLayer class final
- Inheritance
-
- Object
- CanvasLayer
- CanvasOverlayLayer
Constructors
- CanvasOverlayLayer({required CanvasLayerId id, required CanvasTransformWidgetBuilder builder, bool ignorePointer = true, Listenable? listenable})
-
const
Properties
- builder → CanvasTransformWidgetBuilder
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → CanvasLayerId
-
finalinherited
- ignorePointer → bool
-
final
- listenable → Listenable?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited